#
# spec file for package octave-forge-statistics
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  statistics
Name:           octave-forge-%{octpkg}
Version:        1.4.2
Release:        bp154.1.34
Summary:        Additional statistics functions for Octave
License:        GPL-3.0-or-later AND SUSE-Public-Domain
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  octave-devel
Requires:       octave-cli >= 4.0.0
Requires:       octave-forge-io >= 1.0.18

%description
Additional statistics functions.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}

%changelog
* Thu May  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.4.2:
  * canoncorr: allow more variables than observations
  * fitgmdist: return fitgmdist parameters (Bug #57917)
  * gamfit: invert parameter per docs (Bug #57849)
  * geoXXX: update docs 'number of failures (X-1)' =>
    'number of failures (X)' (Bug #57606)
  * kolmogorov_smirnov_test.m: update function handle usage from
    octave6+ (Bug #57351)
  * linkage.m: fix octave6+ parse error (Bug #57348)
  * unifrnd: changed unifrnd(a,a) to return a 0 rather than
    NaN (Bug #56342)
  * updates for usage of deprecated octave functions
- Drop obsolete
  octave-bug-50365-Wrong-distance-results-from-kmeans-and-wrong-centers.patch
* Thu Jul  4 2019 UTC - hiwatari.seiji@gmail.com
- Update to version 1.4.1:
  * update install scripts for octave 5.0 depreciated functions
  * bug fixes to the following functions:
  - pdist2.m: use max in distEucSq (Bug #50377)
  - normpdf: use eps tolerance in tests (Bug #51963)
  - fitgmdist: fix an output bug in fitgmdist
  - t_test: Set tolerance on t_test BISTS (Bug #54557)
  - gpXXXXX: change order of inputs to match matlab (Bug #54009)
  - bartlett_test: df = k-1 (Bug #45894)
  - gppdf: apply scale factor (Bug #54009)
  - gmdistribution: updates for bug #54278, ##54279
  - wishrnd: Bug #55860
  - Add octave-bug-50365-Wrong-distance-results-from-kmeans-and-wrong-centers.patch
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 1.4.0:
  * New functions: canoncorr, fitgmdist, gmdistribution, sigma_pts
  * The following functions have been moved from the statisctics
    package but are condtionally installed: mad
  * The following functions have been moved from octave to be
    condtionally installed:
  - BASE: cloglog, logit, prctile, probit, qqplot table
    (renamed to crosstab)
  - DISTRIBUTIONS: betacdf, betainv, betapdf, betarnd, binocdf,
    binoinv, binopdf, binornd, cauchy_cdf, cauchy_inv,
    cauchy_pdf, cauchy_rnd, chi2cdf, chi2inv, chi2pdf, chi2rnd,
    expcdf, expinv, exppdf, exprnd, fcdf, finv, fpdf, frnd,
    gamcdf, gaminv, gampdf, gamrnd, geocdf, geoinv, geopdf,
    geornd, hygecdf, hygeinv, hygepdf, hygernd,
    kolmogorov_smirnov_cdf, laplace_cdf, laplace_inv,
    laplace_pdf, laplace_rnd, logistic_cdf, logistic_inv,
    logistic_pdf, logistic_rnd, logncdf, logninv, lognpdf,
    lognrnd, nbincdf, nbininv, nbinpdf, nbinrnd, normcdf,
    norminv, normpdf, normrnd, poisscdf, poissinv, poisspdf,
    poissrnd, stdnormal_cdf, stdnormal_inv, stdnormal_pdf,
    stdnormal_rnd, tcdf, tinv, tpdf, trnd, unidcdf, unidinv,
    unidpdf, unidrnd, unifcdf, unifinv, unifpdf, unifrnd,
    wblcdf, wblinv, wblpdf, wblrnd, wienrnd.
  - MODELS: logistic_regression
  - TESTS: anova, bartlett_test, chisquare_test_homogeneity,
    chisquare_test_independence, cor_test, f_test_regression,
    hotelling_test, hotelling_test_2, kolmogorov_smirnov_test,
    kolmogorov_smirnov_test_2, kruskal_wallis_test, manova,
    mcnemar_test, prop_test_2, run_test, sign_test, t_test,
    t_test_2, t_test_regression, u_test, var_test, welch_test,
    wilcoxon_test, z_test, z_test_2.
  * Functions marked with known test failures: grp2idx: bug
    [#51928], gevfir_lmom: bug #31070.
  * Other functions that have been changed for smaller bugfixes, increased
    Matlab compatibility, or performance:
  - dcov: returned dcov instead of dcor. added demo.
  - violin: can be used with subplots. violin quality improved.
  - princomp: Fix expected values of tsquare in unit tests
  - fitgmdist: test number inputs to function
  - hist3: fix removal of rows with NaN values
  * added the packages test data to install
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 1.3.0
  * Bug fixes
  * Number of new functions
* Mon Mar  9 2015 dmitry_r@opensuse.org
- Update to version 1.2.4
  * Made princomp work with nargout < 2.
  * Renamed dendogram to dendrogram.
  * Added isempty check to kmeans.
  * Transposed output of hist3.
  * Converted calculation in hmmviterbi to log space.
  * Bug fixes for stepwisefit, wishrnd.
  * Rewrite of cmdscale for improved compatibility.
  * Fix in squareform for improved compatibility.
  * New cvpartition class, with methods:
    display repartition test training
  * New sample data file fisheriris.txt for tests
  * The following functions are new:
    cdf crossval dcov pdist2 qrandn randsample signtest ttest ttest2
    vartest vartest2 ztest
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 1.2.3
